@@ -1,5 +1,5 @@
 package CPANPLUS::Dist::YACSmoke;
-$CPANPLUS::Dist::YACSmoke::VERSION = '1.06';
+$CPANPLUS::Dist::YACSmoke::VERSION = '1.08';
 # Dist::Zilla: +PodWeaver
 #ABSTRACT: CPANPLUS distribution class that integrates CPAN Testing services into CPANPLUS
 
@@ -97,6 +97,7 @@ my %throw_away;
 		  my $report = shift || "";
 		  my $grade  = shift;
       my $stack = CPANPLUS::Error->stack_as_string;
+      my $cnf   = $mod->parent->configure_object;
 
 		  SWITCH: {
         my $sv = version->new($CPANPLUS::Internals::VERSION) > version->new('0.9116');
@@ -139,6 +140,12 @@ my %throw_away;
 		  if ( $ENV{PERL5_MINISMOKEBOX} ) {
 			$report .= "Powered by minismokebox version " . $ENV{PERL5_MINISMOKEBOX} . "\n";
 		  }
+      if ( $cnf->get_conf( 'prefer_makefile' ) ) {
+        $report .= qq{\nCPANPLUS is prefering Makefile.PL\n};
+      }
+      else {
+        $report .= qq{\nCPANPLUS is prefering Build.PL\n};
+      }
 		  $report .= _gen_report();
 		  return $report;
         },
@@ -375,7 +382,7 @@ CPANPLUS::Dist::YACSmoke - CPANPLUS distribution class that integrates CPAN Test
 
 =head1 VERSION
 
-version 1.06
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -473,7 +480,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+This software is copyright (c) 2019 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
